componenttools.partition_components_once_by_durations_in_seconds_le_without_overhang
====================================================================================

.. autofunction:: abjad.tools.componenttools.partition_components_once_by_durations_in_seconds_le_without_overhang.partition_components_once_by_durations_in_seconds_le_without_overhang
